from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.WindowsConnectNow
import win32more.Windows.Win32.System.Com
WCN_E_PEER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147206143
WCN_E_AUTHENTICATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147206142
WCN_E_CONNECTION_REJECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147206141
WCN_E_SESSION_TIMEDOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147206140
WCN_E_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147206139
WCN_QUERY_CONSTRAINT_USE_SOFTAP: String = 'WCN.Discovery.SoftAP'
WCN_VALUE_DT_CATEGORY_COMPUTER: UInt32 = 1
WCN_VALUE_DT_CATEGORY_INPUT_DEVICE: UInt32 = 2
WCN_VALUE_DT_CATEGORY_PRINTER: UInt32 = 3
WCN_VALUE_DT_CATEGORY_CAMERA: UInt32 = 4
WCN_VALUE_DT_CATEGORY_STORAGE: UInt32 = 5
WCN_VALUE_DT_CATEGORY_NETWORK_INFRASTRUCTURE: UInt32 = 6
WCN_VALUE_DT_CATEGORY_DISPLAY: UInt32 = 7
WCN_VALUE_DT_CATEGORY_MULTIMEDIA_DEVICE: UInt32 = 8
WCN_VALUE_DT_CATEGORY_GAMING_DEVICE: UInt32 = 9
WCN_VALUE_DT_CATEGORY_TELEPHONE: UInt32 = 10
WCN_VALUE_DT_CATEGORY_AUDIO_DEVICE: UInt32 = 11
WCN_VALUE_DT_CATEGORY_OTHER: UInt32 = 255
WCN_VALUE_DT_SUBTYPE_WIFI_OUI: UInt32 = 5304836
WCN_VALUE_DT_SUBTYPE_COMPUTER__PC: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_COMPUTER__SERVER: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_COMPUTER__MEDIACENTER: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_COMPUTER__ULTRAMOBILEPC: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_COMPUTER__NOTEBOOK: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_COMPUTER__DESKTOP: UInt32 = 6
WCN_VALUE_DT_SUBTYPE_COMPUTER__MID: UInt32 = 7
WCN_VALUE_DT_SUBTYPE_COMPUTER__NETBOOK: UInt32 = 8
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__KEYBOARD: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__MOUSE: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__JOYSTICK: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__TRACKBALL: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__GAMECONTROLLER: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__REMOTE: UInt32 = 6
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__TOUCHSCREEN: UInt32 = 7
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__BIOMETRICREADER: UInt32 = 8
WCN_VALUE_DT_SUBTYPE_INPUT_DEVICE__BARCODEREADER: UInt32 = 9
WCN_VALUE_DT_SUBTYPE_PRINTER__PRINTER: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_PRINTER__SCANNER: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_PRINTER__FAX: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_PRINTER__COPIER: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_PRINTER__ALLINONE: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_CAMERA__STILL_CAMERA: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_CAMERA__VIDEO_CAMERA: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_CAMERA__WEB_CAMERA: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_CAMERA__SECURITY_CAMERA: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_STORAGE__NAS: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_NETWORK_INFRASTRUCUTURE__AP: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_NETWORK_INFRASTRUCUTURE__ROUTER: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_NETWORK_INFRASTRUCUTURE__SWITCH: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_NETWORK_INFRASTRUCUTURE__GATEWAY: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_NETWORK_INFRASTRUCUTURE__BRIDGE: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_DISPLAY__TELEVISION: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_DISPLAY__PICTURE_FRAME: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_DISPLAY__PROJECTOR: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_DISPLAY__MONITOR: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_MULTIMEDIA_DEVICE__DAR: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_MULTIMEDIA_DEVICE__PVR: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_MULTIMEDIA_DEVICE__MCX: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_MULTIMEDIA_DEVICE__SETTOPBOX: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_MULTIMEDIA_DEVICE__MEDIA_SERVER_ADAPT_EXT: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_MULTIMEDIA_DEVICE__PVP: UInt32 = 6
WCN_VALUE_DT_SUBTYPE_GAMING_DEVICE__XBOX: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_GAMING_DEVICE__XBOX360: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_GAMING_DEVICE__PLAYSTATION: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_GAMING_DEVICE__CONSOLE_ADAPT: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_GAMING_DEVICE__PORTABLE: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_TELEPHONE__WINDOWS_MOBILE: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_TELEPHONE__PHONE_SINGLEMODE: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_TELEPHONE__PHONE_DUALMODE: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_TELEPHONE__SMARTPHONE_SINGLEMODE: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_TELEPHONE__SMARTPHONE_DUALMODE: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_AUDIO_DEVICE__TUNER_RECEIVER: UInt32 = 1
WCN_VALUE_DT_SUBTYPE_AUDIO_DEVICE__SPEAKERS: UInt32 = 2
WCN_VALUE_DT_SUBTYPE_AUDIO_DEVICE__PMP: UInt32 = 3
WCN_VALUE_DT_SUBTYPE_AUDIO_DEVICE__HEADSET: UInt32 = 4
WCN_VALUE_DT_SUBTYPE_AUDIO_DEVICE__HEADPHONES: UInt32 = 5
WCN_VALUE_DT_SUBTYPE_AUDIO_DEVICE__MICROPHONE: UInt32 = 6
WCN_VALUE_DT_SUBTYPE_AUDIO_DEVICE__HOMETHEATER: UInt32 = 7
WCN_API_MAX_BUFFER_SIZE: UInt32 = 2096
WCN_MICROSOFT_VENDOR_ID: UInt32 = 311
WCN_NO_SUBTYPE: UInt32 = 4294967294
WCN_FLAG_DISCOVERY_VE: UInt32 = 1
WCN_FLAG_AUTHENTICATED_VE: UInt32 = 2
WCN_FLAG_ENCRYPTED_VE: UInt32 = 4
SID_WcnProvider: Guid = Guid('{c100beca-d33a-4a4b-bf23-bbef4663d017}')
PKEY_WCN_DeviceType_Category: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{88190b8b-4684-11da-a26a-0002b3988e81}'), pid=16)
PKEY_WCN_DeviceType_SubCategoryOUI: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{88190b8b-4684-11da-a26a-0002b3988e81}'), pid=17)
PKEY_WCN_DeviceType_SubCategory: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{88190b8b-4684-11da-a26a-0002b3988e81}'), pid=18)
PKEY_WCN_SSID: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{88190b8b-4684-11da-a26a-0002b3988e81}'), pid=32)
class IWCNConnectNotify(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c100be9f-d33a-4a4b-bf23-bbef4663d017}')
    @commethod(3)
    def ConnectSucceeded(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ConnectFailed(self, hrFailure: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWCNDevice(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c100be9c-d33a-4a4b-bf23-bbef4663d017}')
    @commethod(3)
    def SetPassword(self, Type: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_PASSWORD_TYPE, dwPasswordLength: UInt32, pbPassword: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Connect(self, pNotify: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.IWCNConnectNotify) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAttribute(self, AttributeType: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE, dwMaxBufferSize: UInt32, pbBuffer: POINTER(Byte), pdwBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetIntegerAttribute(self, AttributeType: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE, puInteger: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetStringAttribute(self, AttributeType: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE, cchMaxString: UInt32, wszString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetNetworkProfile(self, cchMaxStringLength: UInt32, wszProfile: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetNetworkProfile(self, pszProfileXml: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetVendorExtension(self, pVendorExtSpec: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VENDOR_EXTENSION_SPEC), dwMaxBufferSize: UInt32, pbBuffer: POINTER(Byte), pdwBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetVendorExtension(self, pVendorExtSpec: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VENDOR_EXTENSION_SPEC), cbBuffer: UInt32, pbBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Unadvise(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetNFCPasswordParams(self, Type: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_PASSWORD_TYPE, dwOOBPasswordID: UInt32, dwPasswordLength: UInt32, pbPassword: POINTER(Byte), dwRemotePublicKeyHashLength: UInt32, pbRemotePublicKeyHash: POINTER(Byte), dwDHKeyBlobLength: UInt32, pbDHKeyBlob: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
WCNDeviceObject = Guid('{c100bea7-d33a-4a4b-bf23-bbef4663d017}')
WCN_ATTRIBUTE_TYPE = Int32
WCN_TYPE_AP_CHANNEL: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 0
WCN_TYPE_ASSOCIATION_STATE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 1
WCN_TYPE_AUTHENTICATION_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 2
WCN_TYPE_AUTHENTICATION_TYPE_FLAGS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 3
WCN_TYPE_AUTHENTICATOR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 4
WCN_TYPE_CONFIG_METHODS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 5
WCN_TYPE_CONFIGURATION_ERROR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 6
WCN_TYPE_CONFIRMATION_URL4: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 7
WCN_TYPE_CONFIRMATION_URL6: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 8
WCN_TYPE_CONNECTION_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 9
WCN_TYPE_CONNECTION_TYPE_FLAGS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 10
WCN_TYPE_CREDENTIAL: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 11
WCN_TYPE_DEVICE_NAME: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 12
WCN_TYPE_DEVICE_PASSWORD_ID: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 13
WCN_TYPE_E_HASH1: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 14
WCN_TYPE_E_HASH2: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 15
WCN_TYPE_E_SNONCE1: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 16
WCN_TYPE_E_SNONCE2: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 17
WCN_TYPE_ENCRYPTED_SETTINGS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 18
WCN_TYPE_ENCRYPTION_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 19
WCN_TYPE_ENCRYPTION_TYPE_FLAGS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 20
WCN_TYPE_ENROLLEE_NONCE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 21
WCN_TYPE_FEATURE_ID: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 22
WCN_TYPE_IDENTITY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 23
WCN_TYPE_IDENTITY_PROOF: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 24
WCN_TYPE_KEY_WRAP_AUTHENTICATOR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 25
WCN_TYPE_KEY_IDENTIFIER: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 26
WCN_TYPE_MAC_ADDRESS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 27
WCN_TYPE_MANUFACTURER: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 28
WCN_TYPE_MESSAGE_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 29
WCN_TYPE_MODEL_NAME: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 30
WCN_TYPE_MODEL_NUMBER: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 31
WCN_TYPE_NETWORK_INDEX: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 32
WCN_TYPE_NETWORK_KEY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 33
WCN_TYPE_NETWORK_KEY_INDEX: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 34
WCN_TYPE_NEW_DEVICE_NAME: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 35
WCN_TYPE_NEW_PASSWORD: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 36
WCN_TYPE_OOB_DEVICE_PASSWORD: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 37
WCN_TYPE_OS_VERSION: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 38
WCN_TYPE_POWER_LEVEL: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 39
WCN_TYPE_PSK_CURRENT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 40
WCN_TYPE_PSK_MAX: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 41
WCN_TYPE_PUBLIC_KEY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 42
WCN_TYPE_RADIO_ENABLED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 43
WCN_TYPE_REBOOT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 44
WCN_TYPE_REGISTRAR_CURRENT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 45
WCN_TYPE_REGISTRAR_ESTABLISHED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 46
WCN_TYPE_REGISTRAR_LIST: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 47
WCN_TYPE_REGISTRAR_MAX: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 48
WCN_TYPE_REGISTRAR_NONCE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 49
WCN_TYPE_REQUEST_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 50
WCN_TYPE_RESPONSE_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 51
WCN_TYPE_RF_BANDS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 52
WCN_TYPE_R_HASH1: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 53
WCN_TYPE_R_HASH2: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 54
WCN_TYPE_R_SNONCE1: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 55
WCN_TYPE_R_SNONCE2: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 56
WCN_TYPE_SELECTED_REGISTRAR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 57
WCN_TYPE_SERIAL_NUMBER: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 58
WCN_TYPE_WI_FI_PROTECTED_SETUP_STATE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 59
WCN_TYPE_SSID: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 60
WCN_TYPE_TOTAL_NETWORKS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 61
WCN_TYPE_UUID_E: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 62
WCN_TYPE_UUID_R: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 63
WCN_TYPE_VENDOR_EXTENSION: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 64
WCN_TYPE_VERSION: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 65
WCN_TYPE_X_509_CERTIFICATE_REQUEST: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 66
WCN_TYPE_X_509_CERTIFICATE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 67
WCN_TYPE_EAP_IDENTITY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 68
WCN_TYPE_MESSAGE_COUNTER: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 69
WCN_TYPE_PUBLIC_KEY_HASH: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 70
WCN_TYPE_REKEY_KEY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 71
WCN_TYPE_KEY_LIFETIME: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 72
WCN_TYPE_PERMITTED_CONFIG_METHODS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 73
WCN_TYPE_SELECTED_REGISTRAR_CONFIG_METHODS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 74
WCN_TYPE_PRIMARY_DEVICE_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 75
WCN_TYPE_SECONDARY_DEVICE_TYPE_LIST: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 76
WCN_TYPE_PORTABLE_DEVICE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 77
WCN_TYPE_AP_SETUP_LOCKED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 78
WCN_TYPE_APPLICATION_EXTENSION: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 79
WCN_TYPE_EAP_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 80
WCN_TYPE_INITIALIZATION_VECTOR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 81
WCN_TYPE_KEY_PROVIDED_AUTOMATICALLY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 82
WCN_TYPE_802_1X_ENABLED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 83
WCN_TYPE_APPSESSIONKEY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 84
WCN_TYPE_WEPTRANSMITKEY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 85
WCN_TYPE_UUID: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 86
WCN_TYPE_PRIMARY_DEVICE_TYPE_CATEGORY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 87
WCN_TYPE_PRIMARY_DEVICE_TYPE_SUBCATEGORY_OUI: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 88
WCN_TYPE_PRIMARY_DEVICE_TYPE_SUBCATEGORY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 89
WCN_TYPE_CURRENT_SSID: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 90
WCN_TYPE_BSSID: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 91
WCN_TYPE_DOT11_MAC_ADDRESS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 92
WCN_TYPE_AUTHORIZED_MACS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 93
WCN_TYPE_NETWORK_KEY_SHAREABLE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 94
WCN_TYPE_REQUEST_TO_ENROLL: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 95
WCN_TYPE_REQUESTED_DEVICE_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 96
WCN_TYPE_SETTINGS_DELAY_TIME: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 97
WCN_TYPE_VERSION2: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 98
WCN_TYPE_VENDOR_EXTENSION_WFA: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 99
WCN_NUM_ATTRIBUTE_TYPES: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_ATTRIBUTE_TYPE = 100
WCN_PASSWORD_TYPE = Int32
WCN_PASSWORD_TYPE_PUSH_BUTTON: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_PASSWORD_TYPE = 0
WCN_PASSWORD_TYPE_PIN: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_PASSWORD_TYPE = 1
WCN_PASSWORD_TYPE_PIN_REGISTRAR_SPECIFIED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_PASSWORD_TYPE = 2
WCN_PASSWORD_TYPE_OOB_SPECIFIED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_PASSWORD_TYPE = 3
WCN_PASSWORD_TYPE_WFDS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_PASSWORD_TYPE = 4
WCN_SESSION_STATUS = Int32
WCN_SESSION_STATUS_SUCCESS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_SESSION_STATUS = 0
WCN_SESSION_STATUS_FAILURE_GENERIC: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_SESSION_STATUS = 1
WCN_SESSION_STATUS_FAILURE_TIMEOUT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_SESSION_STATUS = 2
WCN_VALUE_TYPE_ASSOCIATION_STATE = Int32
WCN_VALUE_AS_NOT_ASSOCIATED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ASSOCIATION_STATE = 0
WCN_VALUE_AS_CONNECTION_SUCCESS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ASSOCIATION_STATE = 1
WCN_VALUE_AS_CONFIGURATION_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ASSOCIATION_STATE = 2
WCN_VALUE_AS_ASSOCIATION_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ASSOCIATION_STATE = 3
WCN_VALUE_AS_IP_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ASSOCIATION_STATE = 4
WCN_VALUE_TYPE_AUTHENTICATION_TYPE = Int32
WCN_VALUE_AT_OPEN: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_AUTHENTICATION_TYPE = 1
WCN_VALUE_AT_WPAPSK: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_AUTHENTICATION_TYPE = 2
WCN_VALUE_AT_SHARED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_AUTHENTICATION_TYPE = 4
WCN_VALUE_AT_WPA: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_AUTHENTICATION_TYPE = 8
WCN_VALUE_AT_WPA2: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_AUTHENTICATION_TYPE = 16
WCN_VALUE_AT_WPA2PSK: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_AUTHENTICATION_TYPE = 32
WCN_VALUE_AT_WPAWPA2PSK_MIXED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_AUTHENTICATION_TYPE = 34
WCN_VALUE_TYPE_BOOLEAN = Int32
WCN_VALUE_FALSE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_BOOLEAN = 0
WCN_VALUE_TRUE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_BOOLEAN = 1
WCN_VALUE_TYPE_CONFIGURATION_ERROR = Int32
WCN_VALUE_CE_NO_ERROR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 0
WCN_VALUE_CE_OOB_INTERFACE_READ_ERROR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 1
WCN_VALUE_CE_DECRYPTION_CRC_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 2
WCN_VALUE_CE_2_4_CHANNEL_NOT_SUPPORTED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 3
WCN_VALUE_CE_5_0_CHANNEL_NOT_SUPPORTED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 4
WCN_VALUE_CE_SIGNAL_TOO_WEAK: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 5
WCN_VALUE_CE_NETWORK_AUTHENTICATION_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 6
WCN_VALUE_CE_NETWORK_ASSOCIATION_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 7
WCN_VALUE_CE_NO_DHCP_RESPONSE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 8
WCN_VALUE_CE_FAILED_DHCP_CONFIG: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 9
WCN_VALUE_CE_IP_ADDRESS_CONFLICT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 10
WCN_VALUE_CE_COULD_NOT_CONNECT_TO_REGISTRAR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 11
WCN_VALUE_CE_MULTIPLE_PBC_SESSIONS_DETECTED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 12
WCN_VALUE_CE_ROGUE_ACTIVITY_SUSPECTED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 13
WCN_VALUE_CE_DEVICE_BUSY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 14
WCN_VALUE_CE_SETUP_LOCKED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 15
WCN_VALUE_CE_MESSAGE_TIMEOUT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 16
WCN_VALUE_CE_REGISTRATION_SESSION_TIMEOUT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 17
WCN_VALUE_CE_DEVICE_PASSWORD_AUTH_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIGURATION_ERROR = 18
WCN_VALUE_TYPE_CONFIG_METHODS = Int32
WCN_VALUE_CM_USBA: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 1
WCN_VALUE_CM_ETHERNET: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 2
WCN_VALUE_CM_LABEL: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 4
WCN_VALUE_CM_DISPLAY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 8
WCN_VALUE_CM_EXTERNAL_NFC: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 16
WCN_VALUE_CM_INTEGRATED_NFC: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 32
WCN_VALUE_CM_NFC_INTERFACE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 64
WCN_VALUE_CM_PUSHBUTTON: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 128
WCN_VALUE_CM_KEYPAD: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 256
WCN_VALUE_CM_VIRT_PUSHBUTTON: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 640
WCN_VALUE_CM_PHYS_PUSHBUTTON: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 1152
WCN_VALUE_CM_VIRT_DISPLAY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 8200
WCN_VALUE_CM_PHYS_DISPLAY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONFIG_METHODS = 16392
WCN_VALUE_TYPE_CONNECTION_TYPE = Int32
WCN_VALUE_CT_ESS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONNECTION_TYPE = 1
WCN_VALUE_CT_IBSS: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_CONNECTION_TYPE = 2
WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = Int32
WCN_VALUE_DP_DEFAULT: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 0
WCN_VALUE_DP_USER_SPECIFIED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 1
WCN_VALUE_DP_MACHINE_SPECIFIED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 2
WCN_VALUE_DP_REKEY: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 3
WCN_VALUE_DP_PUSHBUTTON: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 4
WCN_VALUE_DP_REGISTRAR_SPECIFIED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 5
WCN_VALUE_DP_NFC_CONNECTION_HANDOVER: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 7
WCN_VALUE_DP_WFD_SERVICES: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 8
WCN_VALUE_DP_OUTOFBAND_MIN: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 16
WCN_VALUE_DP_OUTOFBAND_MAX: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_DEVICE_PASSWORD_ID = 65535
WCN_VALUE_TYPE_ENCRYPTION_TYPE = Int32
WCN_VALUE_ET_NONE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ENCRYPTION_TYPE = 1
WCN_VALUE_ET_WEP: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ENCRYPTION_TYPE = 2
WCN_VALUE_ET_TKIP: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ENCRYPTION_TYPE = 4
WCN_VALUE_ET_AES: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ENCRYPTION_TYPE = 8
WCN_VALUE_ET_TKIP_AES_MIXED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_ENCRYPTION_TYPE = 12
WCN_VALUE_TYPE_MESSAGE_TYPE = Int32
WCN_VALUE_MT_BEACON: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 1
WCN_VALUE_MT_PROBE_REQUEST: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 2
WCN_VALUE_MT_PROBE_RESPONSE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 3
WCN_VALUE_MT_M1: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 4
WCN_VALUE_MT_M2: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 5
WCN_VALUE_MT_M2D: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 6
WCN_VALUE_MT_M3: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 7
WCN_VALUE_MT_M4: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 8
WCN_VALUE_MT_M5: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 9
WCN_VALUE_MT_M6: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 10
WCN_VALUE_MT_M7: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 11
WCN_VALUE_MT_M8: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 12
WCN_VALUE_MT_ACK: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 13
WCN_VALUE_MT_NACK: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 14
WCN_VALUE_MT_DONE: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_MESSAGE_TYPE = 15
class WCN_VALUE_TYPE_PRIMARY_DEVICE_TYPE(Structure):
    Category: UInt16
    SubCategoryOUI: UInt32
    SubCategory: UInt16
    _pack_ = 1
WCN_VALUE_TYPE_REQUEST_TYPE = Int32
WCN_VALUE_ReqT_ENROLLEE_INFO: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_REQUEST_TYPE = 0
WCN_VALUE_ReqT_ENROLLEE_OPEN_1X: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_REQUEST_TYPE = 1
WCN_VALUE_ReqT_REGISTRAR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_REQUEST_TYPE = 2
WCN_VALUE_ReqT_MANAGER_REGISTRAR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_REQUEST_TYPE = 3
WCN_VALUE_TYPE_RESPONSE_TYPE = Int32
WCN_VALUE_RspT_ENROLLEE_INFO: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_RESPONSE_TYPE = 0
WCN_VALUE_RspT_ENROLLEE_OPEN_1X: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_RESPONSE_TYPE = 1
WCN_VALUE_RspT_REGISTRAR: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_RESPONSE_TYPE = 2
WCN_VALUE_RspT_AP: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_RESPONSE_TYPE = 3
WCN_VALUE_TYPE_RF_BANDS = Int32
WCN_VALUE_RB_24GHZ: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_RF_BANDS = 1
WCN_VALUE_RB_50GHZ: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_RF_BANDS = 2
WCN_VALUE_TYPE_VERSION = Int32
WCN_VALUE_VERSION_1_0: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_VERSION = 16
WCN_VALUE_VERSION_2_0: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_VERSION = 32
WCN_VALUE_TYPE_WI_FI_PROTECTED_SETUP_STATE = Int32
WCN_VALUE_SS_RESERVED00: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_WI_FI_PROTECTED_SETUP_STATE = 0
WCN_VALUE_SS_NOT_CONFIGURED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_WI_FI_PROTECTED_SETUP_STATE = 1
WCN_VALUE_SS_CONFIGURED: win32more.Windows.Win32.NetworkManagement.WindowsConnectNow.WCN_VALUE_TYPE_WI_FI_PROTECTED_SETUP_STATE = 2
class WCN_VENDOR_EXTENSION_SPEC(Structure):
    VendorId: UInt32
    SubType: UInt32
    Index: UInt32
    Flags: UInt32


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.Windows.ApplicationModel.DynamicDependency
import win32more.Windows.ApplicationModel
import win32more.Windows.Win32.System.WinRT
class AddPackageDependencyOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions: ...
    @winrt_mixinmethod
    def get_Rank(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_Rank(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_PrependIfRankCollision(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_PrependIfRankCollision(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions, value: Boolean) -> Void: ...
    PrependIfRankCollision = property(get_PrependIfRankCollision, put_PrependIfRankCollision)
    Rank = property(get_Rank, put_Rank)
class CreatePackageDependencyOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions: ...
    @winrt_mixinmethod
    def get_Architectures(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures: ...
    @winrt_mixinmethod
    def put_Architectures(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures) -> Void: ...
    @winrt_mixinmethod
    def get_VerifyDependencyResolution(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_VerifyDependencyResolution(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_LifetimeArtifactKind(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind: ...
    @winrt_mixinmethod
    def put_LifetimeArtifactKind(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind) -> Void: ...
    @winrt_mixinmethod
    def get_LifetimeArtifact(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_LifetimeArtifact(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: WinRT_String) -> Void: ...
    Architectures = property(get_Architectures, put_Architectures)
    LifetimeArtifact = property(get_LifetimeArtifact, put_LifetimeArtifact)
    LifetimeArtifactKind = property(get_LifetimeArtifactKind, put_LifetimeArtifactKind)
    VerifyDependencyResolution = property(get_VerifyDependencyResolution, put_VerifyDependencyResolution)
DynamicDependencyContract: UInt32 = 131072
class IAddPackageDependencyOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions'
    _iid_ = Guid('{01b801fd-24e3-5e6b-9f1c-805ab410b604}')
    @winrt_commethod(6)
    def get_Rank(self) -> Int32: ...
    @winrt_commethod(7)
    def put_Rank(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_PrependIfRankCollision(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_PrependIfRankCollision(self, value: Boolean) -> Void: ...
    PrependIfRankCollision = property(get_PrependIfRankCollision, put_PrependIfRankCollision)
    Rank = property(get_Rank, put_Rank)
class ICreatePackageDependencyOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions'
    _iid_ = Guid('{cdbb820f-3c69-55dc-a017-b4132574c5d6}')
    @winrt_commethod(6)
    def get_Architectures(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures: ...
    @winrt_commethod(7)
    def put_Architectures(self, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures) -> Void: ...
    @winrt_commethod(8)
    def get_VerifyDependencyResolution(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_VerifyDependencyResolution(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_LifetimeArtifactKind(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind: ...
    @winrt_commethod(11)
    def put_LifetimeArtifactKind(self, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind) -> Void: ...
    @winrt_commethod(12)
    def get_LifetimeArtifact(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_LifetimeArtifact(self, value: WinRT_String) -> Void: ...
    Architectures = property(get_Architectures, put_Architectures)
    LifetimeArtifact = property(get_LifetimeArtifact, put_LifetimeArtifact)
    LifetimeArtifactKind = property(get_LifetimeArtifactKind, put_LifetimeArtifactKind)
    VerifyDependencyResolution = property(get_VerifyDependencyResolution, put_VerifyDependencyResolution)
class IPackageDependency(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency'
    _iid_ = Guid('{32ae7b95-e358-5a48-9669-c97d85ad6556}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def Delete(self) -> Void: ...
    @winrt_commethod(8)
    def Add(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_commethod(9)
    def Add2(self, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    Id = property(get_Id, None)
class IPackageDependencyContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext'
    _iid_ = Guid('{9902c35a-a3f5-5645-af0f-cdf9fca00d5e}')
    @winrt_commethod(6)
    def get_ContextId(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId: ...
    @winrt_commethod(7)
    def get_PackageDependencyId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_PackageFullName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def Remove(self) -> Void: ...
    ContextId = property(get_ContextId, None)
    PackageDependencyId = property(get_PackageDependencyId, None)
    PackageFullName = property(get_PackageFullName, None)
class IPackageDependencyContextFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContextFactory'
    _iid_ = Guid('{9914f24f-bebf-516b-adab-5c3e8bf323f8}')
    @winrt_commethod(6)
    def CreateInstance(self, contextId: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
class IPackageDependencyRankStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyRankStatics'
    _iid_ = Guid('{260583bd-a4ab-53fd-a190-c446bfdb5384}')
    @winrt_commethod(6)
    def get_Default(self) -> Int32: ...
    Default = property(get_Default, None)
class IPackageDependencyStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics'
    _iid_ = Guid('{17b656e1-1a58-5f3c-84a8-4430f6e749c2}')
    @winrt_commethod(6)
    def GetFromId(self, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(7)
    def GetFromIdForSystem(self, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(8)
    def Create(self, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(9)
    def Create2(self, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(10)
    def CreateForSystem(self, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(11)
    def get_GenerationId(self) -> UInt32: ...
    GenerationId = property(get_GenerationId, None)
class IPackageDependencyStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics2'
    _iid_ = Guid('{c7c6e4f3-c0ca-5fdb-bef2-57e6020ffe4e}')
    @winrt_commethod(6)
    def get_PackageGraphRevisionId(self) -> UInt32: ...
    PackageGraphRevisionId = property(get_PackageGraphRevisionId, None)
class _PackageDependency_Meta_(ComPtr.__class__):
    pass
class PackageDependency(ComPtr, metaclass=_PackageDependency_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency'
    @winrt_mixinmethod
    def get_Id(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency) -> WinRT_String: ...
    @winrt_mixinmethod
    def Delete(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency) -> Void: ...
    @winrt_mixinmethod
    def Add(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_mixinmethod
    def Add2(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_classmethod
    def get_PackageGraphRevisionId(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics2) -> UInt32: ...
    @winrt_classmethod
    def GetFromId(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def GetFromIdForSystem(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def Create2(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def CreateForSystem(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def get_GenerationId(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics) -> UInt32: ...
    Id = property(get_Id, None)
    _PackageDependency_Meta_.GenerationId = property(get_GenerationId, None)
    _PackageDependency_Meta_.PackageGraphRevisionId = property(get_PackageGraphRevisionId, None)
class PackageDependencyContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContextFactory, contextId: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_mixinmethod
    def get_ContextId(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId: ...
    @winrt_mixinmethod
    def get_PackageDependencyId(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_PackageFullName(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> WinRT_String: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> Void: ...
    ContextId = property(get_ContextId, None)
    PackageDependencyId = property(get_PackageDependencyId, None)
    PackageFullName = property(get_PackageFullName, None)
class PackageDependencyContextId(Structure):
    Id: UInt64
class PackageDependencyLifetimeArtifactKind(Enum, Int32):
    Process = 0
    FilePath = 1
    RegistryKey = 2
class PackageDependencyProcessorArchitectures(Enum, UInt32):
    None_ = 0
    Neutral = 1
    X86 = 2
    X64 = 4
    Arm = 8
    Arm64 = 16
    X86OnArm64 = 32
class _PackageDependencyRank_Meta_(ComPtr.__class__):
    pass
class PackageDependencyRank(ComPtr, metaclass=_PackageDependencyRank_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyRank'
    @winrt_classmethod
    def get_Default(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyRankStatics) -> Int32: ...
    _PackageDependencyRank_Meta_.Default = property(get_Default, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Console
CONSOLE_TEXTMODE_BUFFER: UInt32 = 1
ATTACH_PARENT_PROCESS: UInt32 = 4294967295
CTRL_C_EVENT: UInt32 = 0
CTRL_BREAK_EVENT: UInt32 = 1
CTRL_CLOSE_EVENT: UInt32 = 2
CTRL_LOGOFF_EVENT: UInt32 = 5
CTRL_SHUTDOWN_EVENT: UInt32 = 6
PSEUDOCONSOLE_INHERIT_CURSOR: UInt32 = 1
CONSOLE_NO_SELECTION: UInt32 = 0
CONSOLE_SELECTION_IN_PROGRESS: UInt32 = 1
CONSOLE_SELECTION_NOT_EMPTY: UInt32 = 2
CONSOLE_MOUSE_SELECTION: UInt32 = 4
CONSOLE_MOUSE_DOWN: UInt32 = 8
HISTORY_NO_DUP_FLAG: UInt32 = 1
CONSOLE_FULLSCREEN: UInt32 = 1
CONSOLE_FULLSCREEN_HARDWARE: UInt32 = 2
CONSOLE_FULLSCREEN_MODE: UInt32 = 1
CONSOLE_WINDOWED_MODE: UInt32 = 2
RIGHT_ALT_PRESSED: UInt32 = 1
LEFT_ALT_PRESSED: UInt32 = 2
RIGHT_CTRL_PRESSED: UInt32 = 4
LEFT_CTRL_PRESSED: UInt32 = 8
SHIFT_PRESSED: UInt32 = 16
NUMLOCK_ON: UInt32 = 32
SCROLLLOCK_ON: UInt32 = 64
CAPSLOCK_ON: UInt32 = 128
ENHANCED_KEY: UInt32 = 256
NLS_DBCSCHAR: UInt32 = 65536
NLS_ALPHANUMERIC: UInt32 = 0
NLS_KATAKANA: UInt32 = 131072
NLS_HIRAGANA: UInt32 = 262144
NLS_ROMAN: UInt32 = 4194304
NLS_IME_CONVERSION: UInt32 = 8388608
ALTNUMPAD_BIT: UInt32 = 67108864
NLS_IME_DISABLE: UInt32 = 536870912
FROM_LEFT_1ST_BUTTON_PRESSED: UInt32 = 1
RIGHTMOST_BUTTON_PRESSED: UInt32 = 2
FROM_LEFT_2ND_BUTTON_PRESSED: UInt32 = 4
FROM_LEFT_3RD_BUTTON_PRESSED: UInt32 = 8
FROM_LEFT_4TH_BUTTON_PRESSED: UInt32 = 16
MOUSE_MOVED: UInt32 = 1
DOUBLE_CLICK: UInt32 = 2
MOUSE_WHEELED: UInt32 = 4
MOUSE_HWHEELED: UInt32 = 8
KEY_EVENT: UInt32 = 1
MOUSE_EVENT: UInt32 = 2
WINDOW_BUFFER_SIZE_EVENT: UInt32 = 4
MENU_EVENT: UInt32 = 8
FOCUS_EVENT: UInt32 = 16
@winfunctype('KERNEL32.dll')
def AllocConsole() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FreeConsole() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def AttachConsole(dwProcessId: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleCP() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleOutputCP() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleMode(hConsoleHandle: win32more.Windows.Win32.Foundation.HANDLE, lpMode: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_MODE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleMode(hConsoleHandle: win32more.Windows.Win32.Foundation.HANDLE, dwMode: win32more.Windows.Win32.System.Console.CONSOLE_MODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetNumberOfConsoleInputEvents(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpNumberOfEvents: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ReadConsoleInputA(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.INPUT_RECORD), nLength: UInt32, lpNumberOfEventsRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ReadConsoleInputW(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.INPUT_RECORD), nLength: UInt32, lpNumberOfEventsRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ReadConsoleInput = UnicodeAlias('ReadConsoleInputW')
@winfunctype('KERNEL32.dll')
def PeekConsoleInputA(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.INPUT_RECORD), nLength: UInt32, lpNumberOfEventsRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def PeekConsoleInputW(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.INPUT_RECORD), nLength: UInt32, lpNumberOfEventsRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
PeekConsoleInput = UnicodeAlias('PeekConsoleInputW')
@winfunctype('KERNEL32.dll')
def ReadConsoleA(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: VoidPtr, nNumberOfCharsToRead: UInt32, lpNumberOfCharsRead: POINTER(UInt32), pInputControl: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_READCONSOLE_CONTROL)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ReadConsoleW(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: VoidPtr, nNumberOfCharsToRead: UInt32, lpNumberOfCharsRead: POINTER(UInt32), pInputControl: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_READCONSOLE_CONTROL)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ReadConsole = UnicodeAlias('ReadConsoleW')
@winfunctype('KERNEL32.dll')
def WriteConsoleA(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: win32more.Windows.Win32.Foundation.PSTR, nNumberOfCharsToWrite: UInt32, lpNumberOfCharsWritten: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def WriteConsoleW(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR, nNumberOfCharsToWrite: UInt32, lpNumberOfCharsWritten: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
WriteConsole = UnicodeAlias('WriteConsoleW')
@winfunctype('KERNEL32.dll')
def SetConsoleCtrlHandler(HandlerRoutine: win32more.Windows.Win32.System.Console.PHANDLER_ROUTINE, Add: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CreatePseudoConsole(size: win32more.Windows.Win32.System.Console.COORD, hInput: win32more.Windows.Win32.Foundation.HANDLE, hOutput: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: UInt32, phPC: POINTER(win32more.Windows.Win32.System.Console.HPCON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def ResizePseudoConsole(hPC: win32more.Windows.Win32.System.Console.HPCON, size: win32more.Windows.Win32.System.Console.COORD) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def ClosePseudoConsole(hPC: win32more.Windows.Win32.System.Console.HPCON) -> Void: ...
@winfunctype('KERNEL32.dll')
def FillConsoleOutputCharacterA(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, cCharacter: win32more.Windows.Win32.Foundation.CHAR, nLength: UInt32, dwWriteCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfCharsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FillConsoleOutputCharacterW(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, cCharacter: Char, nLength: UInt32, dwWriteCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfCharsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
FillConsoleOutputCharacter = UnicodeAlias('FillConsoleOutputCharacterW')
@winfunctype('KERNEL32.dll')
def FillConsoleOutputAttribute(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, wAttribute: UInt16, nLength: UInt32, dwWriteCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfAttrsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GenerateConsoleCtrlEvent(dwCtrlEvent: UInt32, dwProcessGroupId: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CreateConsoleScreenBuffer(dwDesiredAccess: UInt32, dwShareMode: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), dwFlags: UInt32, lpScreenBufferData: VoidPtr) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def SetConsoleActiveScreenBuffer(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FlushConsoleInputBuffer(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleCP(wCodePageID: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleOutputCP(wCodePageID: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleCursorInfo(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpConsoleCursorInfo: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_CURSOR_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleCursorInfo(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpConsoleCursorInfo: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_CURSOR_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleScreenBufferInfo(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpConsoleScreenBufferInfo: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_SCREEN_BUFFER_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleScreenBufferInfoEx(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpConsoleScreenBufferInfoEx: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_SCREEN_BUFFER_INFOEX)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleScreenBufferInfoEx(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpConsoleScreenBufferInfoEx: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_SCREEN_BUFFER_INFOEX)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleScreenBufferSize(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, dwSize: win32more.Windows.Win32.System.Console.COORD) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleCursorPosition(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, dwCursorPosition: win32more.Windows.Win32.System.Console.COORD) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetLargestConsoleWindowSize(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.System.Console.COORD: ...
@winfunctype('KERNEL32.dll')
def SetConsoleTextAttribute(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, wAttributes: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleWindowInfo(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, bAbsolute: win32more.Windows.Win32.Foundation.BOOL, lpConsoleWindow: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def WriteConsoleOutputCharacterA(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpCharacter: win32more.Windows.Win32.Foundation.PSTR, nLength: UInt32, dwWriteCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfCharsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def WriteConsoleOutputCharacterW(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpCharacter: win32more.Windows.Win32.Foundation.PWSTR, nLength: UInt32, dwWriteCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfCharsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
WriteConsoleOutputCharacter = UnicodeAlias('WriteConsoleOutputCharacterW')
@winfunctype('KERNEL32.dll')
def WriteConsoleOutputAttribute(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpAttribute: POINTER(UInt16), nLength: UInt32, dwWriteCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfAttrsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ReadConsoleOutputCharacterA(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpCharacter: win32more.Windows.Win32.Foundation.PSTR, nLength: UInt32, dwReadCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfCharsRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ReadConsoleOutputCharacterW(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpCharacter: win32more.Windows.Win32.Foundation.PWSTR, nLength: UInt32, dwReadCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfCharsRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ReadConsoleOutputCharacter = UnicodeAlias('ReadConsoleOutputCharacterW')
@winfunctype('KERNEL32.dll')
def ReadConsoleOutputAttribute(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpAttribute: POINTER(UInt16), nLength: UInt32, dwReadCoord: win32more.Windows.Win32.System.Console.COORD, lpNumberOfAttrsRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def WriteConsoleInputA(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.INPUT_RECORD), nLength: UInt32, lpNumberOfEventsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def WriteConsoleInputW(hConsoleInput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.INPUT_RECORD), nLength: UInt32, lpNumberOfEventsWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
WriteConsoleInput = UnicodeAlias('WriteConsoleInputW')
@winfunctype('KERNEL32.dll')
def ScrollConsoleScreenBufferA(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpScrollRectangle: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT), lpClipRectangle: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT), dwDestinationOrigin: win32more.Windows.Win32.System.Console.COORD, lpFill: POINTER(win32more.Windows.Win32.System.Console.CHAR_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ScrollConsoleScreenBufferW(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpScrollRectangle: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT), lpClipRectangle: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT), dwDestinationOrigin: win32more.Windows.Win32.System.Console.COORD, lpFill: POINTER(win32more.Windows.Win32.System.Console.CHAR_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ScrollConsoleScreenBuffer = UnicodeAlias('ScrollConsoleScreenBufferW')
@winfunctype('KERNEL32.dll')
def WriteConsoleOutputA(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.CHAR_INFO), dwBufferSize: win32more.Windows.Win32.System.Console.COORD, dwBufferCoord: win32more.Windows.Win32.System.Console.COORD, lpWriteRegion: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def WriteConsoleOutputW(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.CHAR_INFO), dwBufferSize: win32more.Windows.Win32.System.Console.COORD, dwBufferCoord: win32more.Windows.Win32.System.Console.COORD, lpWriteRegion: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
WriteConsoleOutput = UnicodeAlias('WriteConsoleOutputW')
@winfunctype('KERNEL32.dll')
def ReadConsoleOutputA(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.CHAR_INFO), dwBufferSize: win32more.Windows.Win32.System.Console.COORD, dwBufferCoord: win32more.Windows.Win32.System.Console.COORD, lpReadRegion: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ReadConsoleOutputW(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, lpBuffer: POINTER(win32more.Windows.Win32.System.Console.CHAR_INFO), dwBufferSize: win32more.Windows.Win32.System.Console.COORD, dwBufferCoord: win32more.Windows.Win32.System.Console.COORD, lpReadRegion: POINTER(win32more.Windows.Win32.System.Console.SMALL_RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ReadConsoleOutput = UnicodeAlias('ReadConsoleOutputW')
@winfunctype('KERNEL32.dll')
def GetConsoleTitleA(lpConsoleTitle: win32more.Windows.Win32.Foundation.PSTR, nSize: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleTitleW(lpConsoleTitle: win32more.Windows.Win32.Foundation.PWSTR, nSize: UInt32) -> UInt32: ...
GetConsoleTitle = UnicodeAlias('GetConsoleTitleW')
@winfunctype('KERNEL32.dll')
def GetConsoleOriginalTitleA(lpConsoleTitle: win32more.Windows.Win32.Foundation.PSTR, nSize: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleOriginalTitleW(lpConsoleTitle: win32more.Windows.Win32.Foundation.PWSTR, nSize: UInt32) -> UInt32: ...
GetConsoleOriginalTitle = UnicodeAlias('GetConsoleOriginalTitleW')
@winfunctype('KERNEL32.dll')
def SetConsoleTitleA(lpConsoleTitle: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleTitleW(lpConsoleTitle: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetConsoleTitle = UnicodeAlias('SetConsoleTitleW')
@winfunctype('KERNEL32.dll')
def GetNumberOfConsoleMouseButtons(lpNumberOfMouseButtons: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleFontSize(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, nFont: UInt32) -> win32more.Windows.Win32.System.Console.COORD: ...
@winfunctype('KERNEL32.dll')
def GetCurrentConsoleFont(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, bMaximumWindow: win32more.Windows.Win32.Foundation.BOOL, lpConsoleCurrentFont: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_FONT_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCurrentConsoleFontEx(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, bMaximumWindow: win32more.Windows.Win32.Foundation.BOOL, lpConsoleCurrentFontEx: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_FONT_INFOEX)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetCurrentConsoleFontEx(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, bMaximumWindow: win32more.Windows.Win32.Foundation.BOOL, lpConsoleCurrentFontEx: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_FONT_INFOEX)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleSelectionInfo(lpConsoleSelectionInfo: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_SELECTION_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleHistoryInfo(lpConsoleHistoryInfo: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_HISTORY_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleHistoryInfo(lpConsoleHistoryInfo: POINTER(win32more.Windows.Win32.System.Console.CONSOLE_HISTORY_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleDisplayMode(lpModeFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleDisplayMode(hConsoleOutput: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: UInt32, lpNewScreenBufferDimensions: POINTER(win32more.Windows.Win32.System.Console.COORD)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetConsoleWindow() -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('KERNEL32.dll')
def AddConsoleAliasA(Source: win32more.Windows.Win32.Foundation.PSTR, Target: win32more.Windows.Win32.Foundation.PSTR, ExeName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def AddConsoleAliasW(Source: win32more.Windows.Win32.Foundation.PWSTR, Target: win32more.Windows.Win32.Foundation.PWSTR, ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddConsoleAlias = UnicodeAlias('AddConsoleAliasW')
@winfunctype('KERNEL32.dll')
def GetConsoleAliasA(Source: win32more.Windows.Win32.Foundation.PSTR, TargetBuffer: win32more.Windows.Win32.Foundation.PSTR, TargetBufferLength: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleAliasW(Source: win32more.Windows.Win32.Foundation.PWSTR, TargetBuffer: win32more.Windows.Win32.Foundation.PWSTR, TargetBufferLength: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
GetConsoleAlias = UnicodeAlias('GetConsoleAliasW')
@winfunctype('KERNEL32.dll')
def GetConsoleAliasesLengthA(ExeName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleAliasesLengthW(ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
GetConsoleAliasesLength = UnicodeAlias('GetConsoleAliasesLengthW')
@winfunctype('KERNEL32.dll')
def GetConsoleAliasExesLengthA() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleAliasExesLengthW() -> UInt32: ...
GetConsoleAliasExesLength = UnicodeAlias('GetConsoleAliasExesLengthW')
@winfunctype('KERNEL32.dll')
def GetConsoleAliasesA(AliasBuffer: win32more.Windows.Win32.Foundation.PSTR, AliasBufferLength: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleAliasesW(AliasBuffer: win32more.Windows.Win32.Foundation.PWSTR, AliasBufferLength: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
GetConsoleAliases = UnicodeAlias('GetConsoleAliasesW')
@winfunctype('KERNEL32.dll')
def GetConsoleAliasExesA(ExeNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ExeNameBufferLength: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleAliasExesW(ExeNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, ExeNameBufferLength: UInt32) -> UInt32: ...
GetConsoleAliasExes = UnicodeAlias('GetConsoleAliasExesW')
@winfunctype('KERNEL32.dll')
def ExpungeConsoleCommandHistoryA(ExeName: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('KERNEL32.dll')
def ExpungeConsoleCommandHistoryW(ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...
ExpungeConsoleCommandHistory = UnicodeAlias('ExpungeConsoleCommandHistoryW')
@winfunctype('KERNEL32.dll')
def SetConsoleNumberOfCommandsA(Number: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetConsoleNumberOfCommandsW(Number: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetConsoleNumberOfCommands = UnicodeAlias('SetConsoleNumberOfCommandsW')
@winfunctype('KERNEL32.dll')
def GetConsoleCommandHistoryLengthA(ExeName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleCommandHistoryLengthW(ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
GetConsoleCommandHistoryLength = UnicodeAlias('GetConsoleCommandHistoryLengthW')
@winfunctype('KERNEL32.dll')
def GetConsoleCommandHistoryA(Commands: win32more.Windows.Win32.Foundation.PSTR, CommandBufferLength: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetConsoleCommandHistoryW(Commands: win32more.Windows.Win32.Foundation.PWSTR, CommandBufferLength: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
GetConsoleCommandHistory = UnicodeAlias('GetConsoleCommandHistoryW')
@winfunctype('KERNEL32.dll')
def GetConsoleProcessList(lpdwProcessList: POINTER(UInt32), dwProcessCount: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def ConsoleControl(Command: win32more.Windows.Win32.System.Console.CONSOLECONTROL, ConsoleInformation: VoidPtr, ConsoleInformationLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('KERNEL32.dll')
def GetStdHandle(nStdHandle: win32more.Windows.Win32.System.Console.STD_HANDLE) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def SetStdHandle(nStdHandle: win32more.Windows.Win32.System.Console.STD_HANDLE, hHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetStdHandleEx(nStdHandle: win32more.Windows.Win32.System.Console.STD_HANDLE, hHandle: win32more.Windows.Win32.Foundation.HANDLE, phPrevValue: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class CHAR_INFO(Structure):
    Char: _Char_e__Union
    Attributes: UInt16
    class _Char_e__Union(Union):
        UnicodeChar: Char
        AsciiChar: win32more.Windows.Win32.Foundation.CHAR
CONSOLECONTROL = Int32
Reserved1: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 0
ConsoleNotifyConsoleApplication: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 1
Reserved2: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 2
ConsoleSetCaretInfo: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 3
Reserved3: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 4
ConsoleSetForeground: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 5
ConsoleSetWindowOwner: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 6
ConsoleEndTask: win32more.Windows.Win32.System.Console.CONSOLECONTROL = 7
class CONSOLEENDTASK(Structure):
    ProcessId: win32more.Windows.Win32.Foundation.HANDLE
    hwnd: win32more.Windows.Win32.Foundation.HWND
    ConsoleEventCode: UInt32
    ConsoleFlags: UInt32
class CONSOLESETFOREGROUND(Structure):
    hProcess: win32more.Windows.Win32.Foundation.HANDLE
    bForeground: win32more.Windows.Win32.Foundation.BOOL
class CONSOLEWINDOWOWNER(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    ProcessId: UInt32
    ThreadId: UInt32
class CONSOLE_CARET_INFO(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    rc: win32more.Windows.Win32.Foundation.RECT
CONSOLE_CHARACTER_ATTRIBUTES = UInt16
FOREGROUND_BLUE: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 1
FOREGROUND_GREEN: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 2
FOREGROUND_RED: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 4
FOREGROUND_INTENSITY: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 8
BACKGROUND_BLUE: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 16
BACKGROUND_GREEN: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 32
BACKGROUND_RED: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 64
BACKGROUND_INTENSITY: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 128
COMMON_LVB_LEADING_BYTE: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 256
COMMON_LVB_TRAILING_BYTE: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 512
COMMON_LVB_GRID_HORIZONTAL: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 1024
COMMON_LVB_GRID_LVERTICAL: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 2048
COMMON_LVB_GRID_RVERTICAL: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 4096
COMMON_LVB_REVERSE_VIDEO: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 16384
COMMON_LVB_UNDERSCORE: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 32768
COMMON_LVB_SBCSDBCS: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES = 768
class CONSOLE_CURSOR_INFO(Structure):
    dwSize: UInt32
    bVisible: win32more.Windows.Win32.Foundation.BOOL
class CONSOLE_FONT_INFO(Structure):
    nFont: UInt32
    dwFontSize: win32more.Windows.Win32.System.Console.COORD
class CONSOLE_FONT_INFOEX(Structure):
    cbSize: UInt32
    nFont: UInt32
    dwFontSize: win32more.Windows.Win32.System.Console.COORD
    FontFamily: UInt32
    FontWeight: UInt32
    FaceName: Char * 32
class CONSOLE_HISTORY_INFO(Structure):
    cbSize: UInt32
    HistoryBufferSize: UInt32
    NumberOfHistoryBuffers: UInt32
    dwFlags: UInt32
CONSOLE_MODE = UInt32
ENABLE_PROCESSED_INPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 1
ENABLE_LINE_INPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 2
ENABLE_ECHO_INPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 4
ENABLE_WINDOW_INPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 8
ENABLE_MOUSE_INPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 16
ENABLE_INSERT_MODE: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 32
ENABLE_QUICK_EDIT_MODE: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 64
ENABLE_EXTENDED_FLAGS: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 128
ENABLE_AUTO_POSITION: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 256
ENABLE_VIRTUAL_TERMINAL_INPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 512
ENABLE_PROCESSED_OUTPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 1
ENABLE_WRAP_AT_EOL_OUTPUT: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 2
ENABLE_VIRTUAL_TERMINAL_PROCESSING: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 4
DISABLE_NEWLINE_AUTO_RETURN: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 8
ENABLE_LVB_GRID_WORLDWIDE: win32more.Windows.Win32.System.Console.CONSOLE_MODE = 16
class CONSOLE_PROCESS_INFO(Structure):
    dwProcessID: UInt32
    dwFlags: UInt32
class CONSOLE_READCONSOLE_CONTROL(Structure):
    nLength: UInt32
    nInitialChars: UInt32
    dwCtrlWakeupMask: UInt32
    dwControlKeyState: UInt32
class CONSOLE_SCREEN_BUFFER_INFO(Structure):
    dwSize: win32more.Windows.Win32.System.Console.COORD
    dwCursorPosition: win32more.Windows.Win32.System.Console.COORD
    wAttributes: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES
    srWindow: win32more.Windows.Win32.System.Console.SMALL_RECT
    dwMaximumWindowSize: win32more.Windows.Win32.System.Console.COORD
class CONSOLE_SCREEN_BUFFER_INFOEX(Structure):
    cbSize: UInt32
    dwSize: win32more.Windows.Win32.System.Console.COORD
    dwCursorPosition: win32more.Windows.Win32.System.Console.COORD
    wAttributes: win32more.Windows.Win32.System.Console.CONSOLE_CHARACTER_ATTRIBUTES
    srWindow: win32more.Windows.Win32.System.Console.SMALL_RECT
    dwMaximumWindowSize: win32more.Windows.Win32.System.Console.COORD
    wPopupAttributes: UInt16
    bFullscreenSupported: win32more.Windows.Win32.Foundation.BOOL
    ColorTable: win32more.Windows.Win32.Foundation.COLORREF * 16
class CONSOLE_SELECTION_INFO(Structure):
    dwFlags: UInt32
    dwSelectionAnchor: win32more.Windows.Win32.System.Console.COORD
    srSelection: win32more.Windows.Win32.System.Console.SMALL_RECT
class COORD(Structure):
    X: Int16
    Y: Int16
class FOCUS_EVENT_RECORD(Structure):
    bSetFocus: win32more.Windows.Win32.Foundation.BOOL
HPCON = IntPtr
class INPUT_RECORD(Structure):
    EventType: UInt16
    Event: _Event_e__Union
    class _Event_e__Union(Union):
        KeyEvent: win32more.Windows.Win32.System.Console.KEY_EVENT_RECORD
        MouseEvent: win32more.Windows.Win32.System.Console.MOUSE_EVENT_RECORD
        WindowBufferSizeEvent: win32more.Windows.Win32.System.Console.WINDOW_BUFFER_SIZE_RECORD
        MenuEvent: win32more.Windows.Win32.System.Console.MENU_EVENT_RECORD
        FocusEvent: win32more.Windows.Win32.System.Console.FOCUS_EVENT_RECORD
class KEY_EVENT_RECORD(Structure):
    bKeyDown: win32more.Windows.Win32.Foundation.BOOL
    wRepeatCount: UInt16
    wVirtualKeyCode: UInt16
    wVirtualScanCode: UInt16
    uChar: _uChar_e__Union
    dwControlKeyState: UInt32
    class _uChar_e__Union(Union):
        UnicodeChar: Char
        AsciiChar: win32more.Windows.Win32.Foundation.CHAR
class MENU_EVENT_RECORD(Structure):
    dwCommandId: UInt32
class MOUSE_EVENT_RECORD(Structure):
    dwMousePosition: win32more.Windows.Win32.System.Console.COORD
    dwButtonState: UInt32
    dwControlKeyState: UInt32
    dwEventFlags: UInt32
@winfunctype_pointer
def PHANDLER_ROUTINE(CtrlType: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class SMALL_RECT(Structure):
    Left: Int16
    Top: Int16
    Right: Int16
    Bottom: Int16
STD_HANDLE = UInt32
STD_INPUT_HANDLE: win32more.Windows.Win32.System.Console.STD_HANDLE = 4294967286
STD_OUTPUT_HANDLE: win32more.Windows.Win32.System.Console.STD_HANDLE = 4294967285
STD_ERROR_HANDLE: win32more.Windows.Win32.System.Console.STD_HANDLE = 4294967284
class WINDOW_BUFFER_SIZE_RECORD(Structure):
    dwSize: win32more.Windows.Win32.System.Console.COORD


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Perception.Automation.Core
import win32more.Windows.Win32.System.WinRT
class CorePerceptionAutomation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.Automation.Core.CorePerceptionAutomation'
    @winrt_classmethod
    def SetActivationFactoryProvider(cls: win32more.Windows.Perception.Automation.Core.ICorePerceptionAutomationStatics, provider: win32more.Windows.Foundation.IGetActivationFactory) -> Void: ...
class ICorePerceptionAutomationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.Automation.Core.ICorePerceptionAutomationStatics'
    _iid_ = Guid('{0bb04541-4ce2-4923-9a76-8187ecc59112}')
    @winrt_commethod(6)
    def SetActivationFactoryProvider(self, provider: win32more.Windows.Foundation.IGetActivationFactory) -> Void: ...
PerceptionAutomationCoreContract: UInt32 = 65536


make_ready(__name__)
